summary refs log tree commit diff
path: root/gnu/installer/newt/wifi.scm
diff options
context:
space:
mode:
Diffstat (limited to 'gnu/installer/newt/wifi.scm')
-rw-r--r--gnu/installer/newt/wifi.scm8
1 files changed, 4 insertions, 4 deletions
diff --git a/gnu/installer/newt/wifi.scm b/gnu/installer/newt/wifi.scm
index 59e40e327e..4cf5c128e7 100644
--- a/gnu/installer/newt/wifi.scm
+++ b/gnu/installer/newt/wifi.scm
@@ -100,7 +100,7 @@ nmc_wifi_strength_bars."
   "Run a page to inform user that a connection error happened."
   (run-error-page
    (format #f
-           (G_ "An error occured while trying to connect to ~a, please retry.")
+           (G_ "An error occurred while trying to connect to ~a, please retry.")
            service-name)
    (G_ "Connection error")))
 
@@ -160,8 +160,8 @@ of <service-item> records present in LISTBOX."
 ;; Maximum length of a wifi service name.
 (define service-name-max-length (make-parameter 20))
 
-;; Heigth of the listbox displaying wifi services.
-(define wifi-listbox-heigth (make-parameter 20))
+;; Height of the listbox displaying wifi services.
+(define wifi-listbox-height (make-parameter 20))
 
 ;; Information textbox width.
 (define info-textbox-width (make-parameter 40))
@@ -188,7 +188,7 @@ network when the corresponding listbox entry is selected. A button allow to
 force a wifi scan."
   (let* ((listbox (make-listbox
                    -1 -1
-                   (wifi-listbox-heigth)
+                   (wifi-listbox-height)
                    (logior FLAG-SCROLL FLAG-BORDER FLAG-RETURNEXIT)))
          (form (make-form))
          (buttons-grid (make-grid 1 1))